# -*- coding: utf-8 -*-
'''
    Torrenter v2 plugin for XBMC/Kodi
    Copyright (C) 2012-2015 Vadim Skorba v1 - DiMartino v2
    http://forum.kodi.tv/showthread.php?tid=214366

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import re
import sys
import xbmcaddon
import os
import socket

import SearcherABC


class NNMClubRu(SearcherABC.SearcherABC):

    __torrenter_settings__ = xbmcaddon.Addon(id='plugin.video.torrenter')
    #__torrenter_language__ = __settings__.getLocalizedString
    #__torrenter_root__ = __torrenter_settings__.getAddonInfo('path')

    ROOT_PATH=os.path.dirname(__file__)
    addon_id=ROOT_PATH.replace('\\','/').rstrip('/').split('/')[-1]
    __settings__ = xbmcaddon.Addon(id=addon_id)
    __addonpath__ = __settings__.getAddonInfo('path')
    __version__ = __settings__.getAddonInfo('version')
    __plugin__ = __settings__.getAddonInfo('name').replace('Torrenter Searcher: ','') + " v." + __version__

    username = __settings__.getSetting("username")
    password = __settings__.getSetting("password")
    baseurl = 'nnm-club.me'

    '''
    Setting the timeout
    '''
    torrenter_timeout_multi=int(sys.modules["__main__"].__settings__.getSetting("timeout"))
    timeout_multi=int(__settings__.getSetting("timeout"))

    '''
    Weight of source with this searcher provided. Will be multiplied on default weight.
    '''
    sourceWeight = 2

    '''
    Full path to image will shown as source image at result listing
    '''
    searchIcon = os.path.join(__addonpath__,'icon.png')

    '''
    Flag indicates is this source - magnet links source or not.
    '''

    @property
    def isMagnetLinkSource(self):
        return False

    '''
    Main method should be implemented for search process.
    Receives keyword and have to return dictionary of proper tuples:
    filesList.append((
        int(weight),# Calculated global weight of sources
        int(seeds),# Seeds count
        int(leechers),# Leechers count
        str(size),# Full torrent's content size (e.g. 3.04 GB)
        str(title),# Title (will be shown)
        str(link),# Link to the torrent/magnet
        str(image),# Path to image shown at the list
    ))
    '''

    def __init__(self):
        self.logout()

        if self.timeout_multi==0:
            socket.setdefaulttimeout(10+(10*self.torrenter_timeout_multi))
        else:
            socket.setdefaulttimeout(10+(10*(self.timeout_multi-1)))

        if self.__settings__.getSetting("usemirror")=='true':
            self.baseurl = self.__settings__.getSetting("baseurl")

    def logout(self):
        old_username = self.__settings__.getSetting("old_username")
        if old_username in [None,''] or old_username!=self.username:
            self.__settings__.setSetting("old_username", self.username)
            self.clear_cookie(self.baseurl)
        self.login()

    def search(self, keyword):
        filesList = []
        url = "http://%s/forum/tracker.php" % self.baseurl

        data = {
            'prev_sd': '0',
            'prev_a': '0',
            'prev_my': '0',
            'prev_n': '0',
            'prev_shc': '0',
            'prev_shf': '1',
            'prev_sha': '1',
            'prev_shs': '0',
            'prev_shr': '0',
            'prev_sht': '0',
            'o': '10',
            's': '2',
            'tm': '-1',
            'sd': '1',
            'shc': '1',
            'shs': '1',
            'ta': '-1',
            'sns': '-1',
            'sds': '-1',
            'nm': keyword.decode('utf-8').encode('cp1251'),
            'submit': '%CF%EE%E8%F1%EA'}

        headers = [('Origin', 'http://%s' % self.baseurl),
                   ('User-Agent',
                    'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062.124 YaBrowser/14.10.2062.12061 Safari/537.36'),
                   ('Referer', 'http://%s/forum/tracker.php?def=1' % self.baseurl)]

        response = self.makeRequest(url, data=data, headers=headers)
        if None != response and 0 < len(response):
            response = response.decode('cp1251').encode('utf-8')
            #self.check_login(response)
            #print response
            forums = [24, 27, 23, 14, 26, 15]
            regex = '''<tr class=.+?</tr>'''
            regex_tr = '<a class="gen" href="tracker\.php\?c=(\d+)&nm=.+?href="viewtopic\.php\?t=(\d+)"><b>(.+?)</b>.+?<td align="center" nowrap="nowrap">(?=#</td>|<a href="download\.php\?id=(\d+)".+?</td>).+?<td .+?><u>\d+?</u> (.+?)</td>.+?<td.+?title="Seeders".+?<b>(\d+)</b>.+?<td .+?title="Leechers".+?<b>(\d+)</b>.+?</tr>'
            for tr in re.compile(regex, re.DOTALL).findall(response):
                result=re.compile(regex_tr, re.DOTALL).findall(tr)
                #print str(result)
                if result:
                    (forum, topic, title, link, size, seeds, leechers)=result[0]
                    if int(forum) in forums and link not in ['', None]:
                        link = 'http://%s/forum/download.php?id=%s&%s' % (self.baseurl, link, topic)
                        filesList.append((
                            int(int(self.sourceWeight) * int(seeds)),
                            int(seeds), int(leechers), size,
                            self.unescape(self.stripHtml(title)),
                            self.__class__.__name__ + '::' + link,
                            self.searchIcon,
                        ))
        return filesList

    def check_login(self, response=None):
        if None != response and 0 < len(response):
            if re.compile('<a href="login.php" class="mainmenu">').search(response):
                print 'NNM-Club Not logged!'
                self.login()
                return False
        return True

    def getTorrentFile(self, url):
        self.timeout(5)

        referer = 'http://%s/forum/viewtopic.php?t=%s' % (self.baseurl, re.search('(\d+)$', url).group(1))
        #print url

        headers=[('Referer', referer)]
        content = self.makeRequest(url,headers=headers)

        if not self.check_login(content):
            content = self.makeRequest(url,headers=headers)

        return self.saveTorrentFile(url, content)

    def login(self):
        data = {
            'password': self.password,
            'username': self.username,
            'login': '%C2%F5%EE%E4',
            'redirect': 'index.php',
            'autologin': 'on'
        }
        self.makeRequest(
            'http://%s/forum/login.php' % self.baseurl,
            data
        )
        self.cookieJar.save(ignore_discard=True)
        for cookie in self.cookieJar:
            if cookie.name == 'phpbb2mysql_4_sid' and cookie.domain=='.%s' % self.baseurl:
                return 'phpbb2mysql_4_sid=' + cookie.value
        return False